==> qip-catalog-library-0.1.4-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/system/AbstractSystemEntity.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity.system;

import jakarta.persistence.MappedSuperclass;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.apache.commons.lang3.StringUtils;
import org.hibernate.proxy.HibernateProxy;
import org.qubership.integration.platform.catalog.persistence.configs.entity.AbstractEntity;

import java.util.Objects;

@MappedSuperclass
@SuperBuilder
@NoArgsConstructor
public abstract class AbstractSystemEntity extends AbstractEntity {

    @Override
    public boolean equals(Object object) {
        return equals(object, true);
    }

    public boolean equals(Object object, boolean strict) {
        if (this == object) {
            return true;
        }
        if (object == null) {
            return false;
        }
        Class<?> oEffectiveClass = object instanceof HibernateProxy
                ? ((HibernateProxy) object).getHibernateLazyInitializer().getPersistentClass()
                : object.getClass();
        Class<?> thisEffectiveClass = this instanceof HibernateProxy
                ? ((HibernateProxy) this).getHibernateLazyInitializer().getPersistentClass()
                : this.getClass();
        if (thisEffectiveClass != oEffectiveClass) {
            return false;
        }
        AbstractSystemEntity that = (AbstractSystemEntity) object;
        return (!strict || StringUtils.equals(this.getId(), that.getId()))
                && StringUtils.equals(this.getName(), that.getName())
                && StringUtils.equals(this.getDescription(), that.getDescription());
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, name, description);
    }
}

==> qip-catalog-library-2025.1.0.12-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/system/AbstractSystemEntity.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity.system;

import jakarta.persistence.MappedSuperclass;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.apache.commons.lang3.StringUtils;
import org.hibernate.proxy.HibernateProxy;

import org.qubership.integration.platform.catalog.persistence.configs.entity.AbstractEntity;

import java.util.Objects;

@MappedSuperclass
@SuperBuilder
@NoArgsConstructor
public abstract class AbstractSystemEntity extends AbstractEntity {

    @Override
    public boolean equals(Object object) {
        return equals(object, true);
    }

    public boolean equals(Object object, boolean strict) {
        if (this == object) return true;
        if (object == null) return false;
        Class<?> oEffectiveClass = object instanceof HibernateProxy ?
                ((HibernateProxy) object).getHibernateLazyInitializer().getPersistentClass() : object.getClass();
        Class<?> thisEffectiveClass = this instanceof HibernateProxy ?
                ((HibernateProxy) this).getHibernateLazyInitializer().getPersistentClass() : this.getClass();
        if (thisEffectiveClass != oEffectiveClass) return false;
        AbstractSystemEntity that = (AbstractSystemEntity) object;
        return (!strict || StringUtils.equals(this.getId(), that.getId())) &&
                StringUtils.equals(this.getName(), that.getName()) &&
                StringUtils.equals(this.getDescription(), that.getDescription());
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, name, description);
    }
}
